@@ -25,7 +25,7 @@ class DltkAiClient:
                 DltkAiClient: Client object for DltkAi.
         """
         self.api_key = api_key
-        self.base_url = "https://dev-kong.dltk.ai"
+        self.base_url = "https://prod-kong.dltk.ai"
 
     def sentiment_analysis(self, text):
         """
